==> carrent-ke-uikit-0.1.1.tgz: package/src/components/MarketingHeader/index.js <==
/* This example requires Tailwind CSS v2.0+ */
import { Fragment } from 'react'
import { Disclosure, Menu, Transition } from '@headlessui/react'
import { BellIcon, MenuIcon, XIcon,LoginIcon  } from '@heroicons/react/outline'
import { SparklesIcon } from '@heroicons/react/solid';

import Logo from '../../assets/logos/logo.svg'
import LogoMark from '../../assets/logos/logo_mark.svg';

function classNames(...classes) {
  return classes.filter(Boolean).join(' ')
}

const MarketingHeader = () => {
  return (
    <Disclosure as="nav" className="bg-white">
      {({ open }) => (
        <>
          <div className="max-w-7xl mx-auto ">
            <div className="flex justify-between h-16">
              <div className="flex">
                <div className="flex-shrink-0 flex items-center">
                  <img
                    className="block lg:hidden h-8 w-auto"
                    src={LogoMark}
                    alt="Workflow"
                  />
                  <img
                    className="hidden lg:block h-8 w-auto"
                    src={Logo}
                    alt="Workflow"
                  />
                </div>
              </div>
              <div className="space-x-4 hidden md:block">
                  <button
                    type="button"
                    className="relative inline-flex items-center px-4 py-2 border border-transparent text-sm font-medium rounded-md text-white bg-blue-600 shadow-sm hover:bg-blue-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500"
                  >
                    <SparklesIcon className="-ml-1 mr-2 h-5 w-5" aria-hidden="true" />
                    <span>Become A Partner</span>
                  </button>
                  <button
                    type="button"
                    className="relative inline-flex items-center px-4 py-2 border border-transparent text-sm font-medium rounded-md text-gray-700 bg-white hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500"
                  >
                    <LoginIcon className="-ml-1 mr-2 h-5 w-5" aria-hidden="true" />
                    <span>Login/Register</span>
                  </button>
                </div>
              <div className="-mr-2 flex items-center sm:hidden">
                {/* Mobile menu button */}
                <Disclosure.Button className="inline-flex items-center justify-center p-2 rounded-md text-gray-400 hover:text-gray-500 hover:bg-gray-100 focus:outline-none focus:ring-2 focus:ring-inset focus:ring-indigo-500">
                  <span className="sr-only">Open main menu</span>
                  {open ? (
                    <XIcon className="block h-6 w-6" aria-hidden="true" />
                  ) : (
                    <MenuIcon className="block h-6 w-6" aria-hidden="true" />
                  )}
                </Disclosure.Button>
              </div>
            </div>
          </div>

          <Disclosure.Panel className="sm:hidden">
            <div className="pt-2 pb-3 space-y-1 shadow rounded-md">
              {/* Current: "bg-indigo-50 border-indigo-500 text-indigo-700", Default: "border-transparent text-gray-500 hover:bg-gray-50 hover:border-gray-300 hover:text-gray-700" */}
              <a
                href="#"
                className="bg-indigo-50 border-blue-500 text-blue-700 block pl-3 pr-4 py-2 border-l-4 text-base font-medium"
              >
                Become A Partner
              </a>
              <a
                href="#"
                className="border-transparent text-gray-500 hover:bg-gray-50 hover:border-gray-300 hover:text-gray-700 block pl-3 pr-4 py-2 border-l-4 text-base font-medium"
              >
                Login/Register
              </a>
            </div>
          </Disclosure.Panel>
        </>
      )}
    </Disclosure>
  )
}



MarketingHeader.propTypes = {
};
export default MarketingHeader;

// export const Header = ({ user, onLogin, onLogout, onCreateAccount }) => (
//   <header>
//     <div className="wrapper">
//       <div>
//         <svg width="32" height="32" viewBox="0 0 32 32" xmlns="http://www.w3.org/2000/svg">
//           <g fill="none" fillRule="evenodd">
//             <path
//               d="M10 0h12a10 10 0 0110 10v12a10 10 0 01-10 10H10A10 10 0 010 22V10A10 10 0 0110 0z"
//               fill="#FFF"
//             />
//             <path
//               d="M5.3 10.6l10.4 6v11.1l-10.4-6v-11zm11.4-6.2l9.7 5.5-9.7 5.6V4.4z"
//               fill="#555AB9"
//             />
//             <path
//               d="M27.2 10.6v11.2l-10.5 6V16.5l10.5-6zM15.7 4.4v11L6 10l9.7-5.5z"
//               fill="#91BAF8"
//             />
//           </g>
//         </svg>
//         <h1>Acme</h1>
//       </div>
//       <div>
//         {user ? (
//           <Button size="small" onClick={onLogout} label="Log out" />
//         ) : (
//           <>
//             <Button size="small" onClick={onLogin} label="Log in" />
//             <Button primary size="small" onClick={onCreateAccount} label="Sign up" />
//           </>
//         )}
//       </div>
//     </div>
//   </header>
// );

==> carrent-ke-uikit-0.1.6.tgz: package/src/components/MarketingHeader/index.js <==
/* This example requires Tailwind CSS v2.0+ */
import { Disclosure } from '@headlessui/react'
import {  MenuIcon, XIcon,LoginIcon  } from '@heroicons/react/outline'
import { SparklesIcon } from '@heroicons/react/solid';
import PropTypes from 'prop-types'

const MarketingHeader = ({ logo, logoMark }) => {
  return (
    <Disclosure as="nav" className="bg-white">
      {({ open }) => (
        <>
          <div className="max-w-7xl mx-auto ">
            <div className="flex justify-between h-16">
              <div className="flex">
                <div className="flex-shrink-0 flex items-center">
                  <img
                    className="block lg:hidden h-8 w-auto"
                    src={logoMark.url}
                    alt="Workflow"
                  />
                  <img
                    className="hidden lg:block h-8 w-auto"
                    src={logo.url}
                    alt="Workflow"
                  />
                </div>
              </div>
              <div className="space-x-4 hidden md:block">
                  <button
                    type="button"
                    className="relative inline-flex items-center px-4 py-2 border border-transparent text-sm font-medium rounded-md text-white bg-blue-600 shadow-sm hover:bg-blue-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500"
                  >
                    <SparklesIcon className="-ml-1 mr-2 h-5 w-5" aria-hidden="true" />
                    <span>Become A Partner</span>
                  </button>
                  <button
                    type="button"
                    className="relative inline-flex items-center px-4 py-2 border border-transparent text-sm font-medium rounded-md text-gray-700 bg-white hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-indigo-500"
                  >
                    <LoginIcon className="-ml-1 mr-2 h-5 w-5" aria-hidden="true" />
                    <span>Login/Register</span>
                  </button>
                </div>
              <div className="-mr-2 flex items-center sm:hidden">
                {/* Mobile menu button */}
                <Disclosure.Button className="inline-flex items-center justify-center p-2 rounded-md text-gray-400 hover:text-gray-500 hover:bg-gray-100 focus:outline-none focus:ring-2 focus:ring-inset focus:ring-indigo-500">
                  <span className="sr-only">Open main menu</span>
                  {open ? (
                    <XIcon className="block h-6 w-6" aria-hidden="true" />
                  ) : (
                    <MenuIcon className="block h-6 w-6" aria-hidden="true" />
                  )}
                </Disclosure.Button>
              </div>
            </div>
          </div>

          <Disclosure.Panel className="sm:hidden">
            <div className="pt-2 pb-3 space-y-1 shadow rounded-md">
              {/* Current: "bg-indigo-50 border-indigo-500 text-indigo-700", Default: "border-transparent text-gray-500 hover:bg-gray-50 hover:border-gray-300 hover:text-gray-700" */}
              <a
                href="#"
                className="bg-indigo-50 border-blue-500 text-blue-700 block pl-3 pr-4 py-2 border-l-4 text-base font-medium"
              >
                Become A Partner
              </a>
              <a
                href="#"
                className="border-transparent text-gray-500 hover:bg-gray-50 hover:border-gray-300 hover:text-gray-700 block pl-3 pr-4 py-2 border-l-4 text-base font-medium"
              >
                Login/Register
              </a>
            </div>
          </Disclosure.Panel>
        </>
      )}
    </Disclosure>
  )
}



MarketingHeader.propTypes = {
  logo:PropTypes.shape({
    url: PropTypes.string.isRequired
  }).isRequired,
  logoMark:PropTypes.shape({
    url: PropTypes.string.isRequired
  }).isRequired
};
export default MarketingHeader;
